@@ -1,7 +1,9 @@
-package Monitoring::Icinga2::Client::Simple;
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_08'; # TRIAL
+# ABSTRACT: Simpler REST client for Icinga2
 
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100008';use strict;
+package Monitoring::Icinga2::Client::Simple;
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_09'; # TRIAL
+
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100009';use strict;
 use warnings;
 use 5.010_001;
 use Monitoring::Icinga2::Client::REST 2;
@@ -282,11 +284,11 @@ __END__
 
 =head1 NAME
 
-Monitoring::Icinga2::Client::Simple
+Monitoring::Icinga2::Client::Simple - Simpler REST client for Icinga2
 
 =head1 VERSION
 
-version 0.001000_08
+version 0.001000_09
 
 =head1 SYNOPSIS
 
